#!/bin/sh
# -------
# File:        update-cddt-pkg-scripts.d
# Description: Simple script to enable / disable cddt pkg-scripts.d
# Author:      Sergio Talens-Oliag <sto@debian.org>
# Copyright:   (c) 2006 Sergio Talens-Oliag <sto@debian.org>
# SVN Id:      $Id: update-cddt-pkg-scripts.d 392 2006-03-04 22:07:58Z sto $
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along 
# with this program; if not, write to the Free Software Foundation, Inc., 
# 51 Franklin St, Fifth Floor, Boston MA 02110-1301 USA
# --------

# Check PATH
if [ -z "`which cddt.sh`" ]; then
  # If 'cddt.sh' is not available on the current PATH, add standard PATH
  # components to this script.
  PATH="$PATH:/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"
fi

# Use noninteractive frontend by default
[ -z "$SSFT_FRONTEND" ] && SSFT_FRONTEND="noninteractive"

# Load functions and set up defaults
. cddt.sh && cddt_initialize || exit 1

# Use cddt_textdomain
cddt_set_textdomain

# ---------
# VARIABLES
# ---------

AVAIL_DIR="$CDDT_APT_AVAIL_SCRIPTS"
ENABL_DIR="$CDDT_APT_ENABL_SCRIPTS"

# ---------
# FUNCTIONS
# ---------

# Function: usage
#
# Description: Show command usage
usage() {
  local progname="$0"
  local MSG=$(eval_gettext \
    "Usage: \$progname OPTION SCRIPTS_LIST

Where OPTION is one of [ enable | disable | hide | show | status ]
and SCRIPTS_LIST is a list of script names to work with")
  echo "$MSG" 
}

# ====
# MAIN
# ====
case "$1" in
enable)
  shift
  cddt_scripts_enable "$AVAIL_DIR" "$ENABL_DIR" "$@"
  ;;
disable)
  shift
  cddt_scripts_disable "$AVAIL_DIR" "$ENABL_DIR" "$@"
  ;;
hide)
  shift
  cddt_scripts_hide "$AVAIL_DIR" "$ENABL_DIR" "$@"
  ;;
show)
  shift
  cddt_scripts_show "$AVAIL_DIR" "$ENABL_DIR" "$@"
  ;;
status)
  shift
  cddt_scripts_status "$AVAIL_DIR" "$ENABL_DIR" "$@"
  ;;
*)
  usage >&2
  ;;
esac

exit 0

# ------
# SVN Id: $Id: update-cddt-pkg-scripts.d 392 2006-03-04 22:07:58Z sto $
